#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
# @Version     : Python 3.11.4
# @Software    : Sublime Text 4
# @Author      : StudentCWZ
# @Email       : StudentCWZ@outlook.com
# @Date        : 2023/11/4 11:15
# @File        : env.py
# @Description :
"""

import os
from typing import Union


class EnvVarHelper:
    """
    A helper class for handling environment variables.
    """

    @property
    def consul_vars(self) -> dict:
        """
        Get the consul-related environment variables.

        :return: a dict containing the consul-related environment variables.
        """
        return {
            'host': os.environ.get('CONSUL_HOST', 'localhost'),
            'port': os.environ.get('CONSUL_PORT', 8500),
            'dc': os.environ.get('CONSUL_DC', 'dc1'),
            'token': os.getenv('CONSUL_TOKEN', None),
            'key': os.getenv('CONSUL_KEY', None),
        }

    def __getattr__(self, name: str) -> Union[dict, None]:
        """
        Get an environment variable as an attribute.

        :param name: The name of the environment variable.
        :return: The value of the environment variable, or None if it does not exist.
        """
        return os.environ.get(name)
